# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### Cluster <a name="cdk-eksdistro.Cluster"></a>

Represents the EKS-D cluster.

#### Initializers <a name="cdk-eksdistro.Cluster.Initializer"></a>

```typescript
import { Cluster } from 'cdk-eksdistro'

new Cluster(scope: Construct, id: string, props?: ClusterProps)
```

##### `scope`<sup>Required</sup> <a name="cdk-eksdistro.Cluster.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `id`<sup>Required</sup> <a name="cdk-eksdistro.Cluster.parameter.id"></a>

- *Type:* `string`

---

##### `props`<sup>Optional</sup> <a name="cdk-eksdistro.Cluster.parameter.props"></a>

- *Type:* [`cdk-eksdistro.ClusterProps`](#cdk-eksdistro.ClusterProps)

---





## Structs <a name="Structs"></a>

### ClusterProps <a name="cdk-eksdistro.ClusterProps"></a>

Construct properties for the EKS-D cluster.

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { ClusterProps } from 'cdk-eksdistro'

const clusterProps: ClusterProps = { ... }
```

##### `capacitySize`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.capacitySize"></a>

```typescript
public readonly capacitySize: number;
```

- *Type:* `number`
- *Default:* 1

number of instances.

---

##### `defaultInstanceType`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.defaultInstanceType"></a>

```typescript
public readonly defaultInstanceType: InstanceType;
```

- *Type:* [`@aws-cdk/aws-ec2.InstanceType`](#@aws-cdk/aws-ec2.InstanceType)
- *Default:* t3.large

The default EC2 instance type.

---

##### `machineImage`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.machineImage"></a>

```typescript
public readonly machineImage: IMachineImage;
```

- *Type:* [`@aws-cdk/aws-ec2.IMachineImage`](#@aws-cdk/aws-ec2.IMachineImage)
- *Default:* The latest AMI from ubuntu-focal-20.04-amd64-server

AMI for the EKS-D instance node.

---

##### `outputAmiId`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.outputAmiId"></a>

```typescript
public readonly outputAmiId: boolean;
```

- *Type:* `boolean`
- *Default:* true

Print AMI ID in the output.

---

##### `spot`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.spot"></a>

```typescript
public readonly spot: boolean;
```

- *Type:* `boolean`
- *Default:* false

Create EC2 spot instnce for the cluster node.

---

##### `vpc`<sup>Optional</sup> <a name="cdk-eksdistro.ClusterProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* [`@aws-cdk/aws-ec2.IVpc`](#@aws-cdk/aws-ec2.IVpc)
- *Default:* get or create a VPC

VPC for the cluster.

---

## Classes <a name="Classes"></a>

### UbumtuAmiProvider <a name="cdk-eksdistro.UbumtuAmiProvider"></a>

The AMI provider to get the latest Ubuntu Linux AMI.

#### Initializers <a name="cdk-eksdistro.UbumtuAmiProvider.Initializer"></a>

```typescript
import { UbumtuAmiProvider } from 'cdk-eksdistro'

new UbumtuAmiProvider(scope: Construct, userData: UserData)
```

##### `scope`<sup>Required</sup> <a name="cdk-eksdistro.UbumtuAmiProvider.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `userData`<sup>Required</sup> <a name="cdk-eksdistro.UbumtuAmiProvider.parameter.userData"></a>

- *Type:* [`@aws-cdk/aws-ec2.UserData`](#@aws-cdk/aws-ec2.UserData)

---



#### Properties <a name="Properties"></a>

##### `amiId`<sup>Required</sup> <a name="cdk-eksdistro.UbumtuAmiProvider.property.amiId"></a>

```typescript
public readonly amiId: IMachineImage;
```

- *Type:* [`@aws-cdk/aws-ec2.IMachineImage`](#@aws-cdk/aws-ec2.IMachineImage)

---

##### `scope`<sup>Required</sup> <a name="cdk-eksdistro.UbumtuAmiProvider.property.scope"></a>

```typescript
public readonly scope: Construct;
```

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `userData`<sup>Required</sup> <a name="cdk-eksdistro.UbumtuAmiProvider.property.userData"></a>

```typescript
public readonly userData: UserData;
```

- *Type:* [`@aws-cdk/aws-ec2.UserData`](#@aws-cdk/aws-ec2.UserData)

---



## Enums <a name="Enums"></a>

### SpotInstanceType <a name="SpotInstanceType"></a>

#### `ONE_TIME` <a name="cdk-eksdistro.SpotInstanceType.ONE_TIME"></a>

---


#### `PERSISTENT` <a name="cdk-eksdistro.SpotInstanceType.PERSISTENT"></a>

---

